import request from '@/utils/request'

// 查询个微账号列表
export function listCompanyAccount(query) {
  return request({
    url: '/company/companyWx/list',
    method: 'get',
    params: query
  })
}

// 查询个微账号列表
export function companyListAll(query) {
  return request({
    url: '/company/companyWx/companyListAll',
    method: 'get',
    params: query
  })
}
// 查询个微账号列表
export function listAll(query) {
  return request({
    url: '/company/companyWx/listAll',
    method: 'get',
    params: query
  })
}

// 查询个微账号详细
export function getCompanyAccount(id) {
  return request({
    url: '/company/companyWx/' + id,
    method: 'get'
  })
}

// 新增个微账号
export function addCompanyAccount(data) {
  return request({
    url: '/company/companyWx',
    method: 'post',
    data: data
  })
}

// 修改个微账号
export function updateCompanyAccount(data) {
  return request({
    url: '/company/companyWx',
    method: 'put',
    data: data
  })
}

// 删除个微账号
export function delCompanyAccount(id) {
  return request({
    url: '/company/companyWx/' + id,
    method: 'delete'
  })
}

// 导出个微账号
export function exportCompanyAccount(query) {
  return request({
    url: '/company/companyWx/export',
    method: 'get',
    params: query
  })
}
// 导出个微账号
export function getWxQrCode(query) {
  return request({
    url: '/company/companyWx/getWxQrCode',
    method: 'get',
    params: query
  })
}

// 导出个微账号
export function getLoginStatus(query) {
  return request({
    url: '/company/companyWx/getLoginStatus',
    method: 'get',
    params: query
  })
}
// 导出个微账号
export function bindService(query) {
  return request({
    url: '/company/companyWx/bindService',
    method: 'get',
    params: query
  })
}
// 导出个微账号
export function wakeUpLogin(query) {
  return request({
    url: '/company/companyWx/wakeUpLogin',
    method: 'get',
    params: query
  })
}
// 导出个微账号
export function updateWxInfo(query) {
  return request({
    url: '/company/companyWx/updateWxInfo',
    method: 'get',
    params: query
  })
}
// 导出个微账号
export function wxLoginOut(query) {
  return request({
    url: '/company/companyWx/wxLoginOut',
    method: 'get',
    params: query
  })
}
export function syncWx(query) {
  return request({
    url: '/company/companyWx/syncWx',
    method: 'get',
    params: query
  })
}

// 查询我的个微账号列表
export function myListCompanyAccount(query) {
  return request({
    url: '/company/companyWx/myList',
    method: 'get',
    params: query
  })
}

// 新增我的个微账号
export function addMyCompanyAccount(data) {
  return request({
    url: '/company/companyWx/myAdd',
    method: 'post',
    data: data
  })
}

// 修改我的个微账号
export function updateMyCompanyAccount(data) {
  return request({
    url: '/company/companyWx/myEdit',
    method: 'put',
    data: data
  })
}

// 删除我的个微账号
export function delMyCompanyAccount(id) {
  return request({
    url: '/company/companyWx/my/' + id,
    method: 'delete'
  })
}

// 导出我的个微账号
export function exportMyCompanyAccount(query) {
  return request({
    url: '/company/companyWx/myExport',
    method: 'get',
    params: query
  })
}
